# Roman Attribute Dictionary


This is a repository for the Roman Attribute Dictionary


## Installation

To install the latest `rad` release

    pip install rad

To install the latest code from the repository

    pip install git+https://github.com/spacetelescope/rad.git

To use the library

    >>> import rad
